/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cocoon.servletservice.spring;

import org.apache.cocoon.servletservice.CallStackHelper;
import org.apache.cocoon.servletservice.ServletServiceContext;
import org.springframework.beans.factory.FactoryBean;

/**
 * Factorybean that exposes the ServletContext in the current base call frame.
 * It will typically be used together with the call scope for servlet services.
 *
 * @version $Id: BaseServletContextFactoryBean.java 562806 2007-08-05 02:26:41Z vgritsenko $
 */
public final class BaseServletContextFactoryBean implements FactoryBean {

    /* (non-Javadoc)
     * @see org.springframework.beans.factory.FactoryBean#getObject()
     */
    public Object getObject() throws Exception {
        return CallStackHelper.getBaseServletContext();
    }

    /* (non-Javadoc)
     * @see org.springframework.beans.factory.FactoryBean#getObjectType()
     */
    public Class getObjectType() {
        // A ServletServiceContext rather than a ServletContext is needed to make the
        // Absolutizable interface available through the ScopedProxyFactoryBean
        return ServletServiceContext.class;
    }

    /* (non-Javadoc)
     * @see org.springframework.beans.factory.FactoryBean#isSingleton()
     */
    public boolean isSingleton() {
        return true;
    }
}
